| Title: | Extremely fast rasterization engine built in Rust for R |
|---|---|
| Description: | Rasterization engine that handles all sf-supported geometries and returns a terra object. |
| Authors: | Tommaso Trotto [aut, cre] |
| Maintainer: | Tommaso Trotto <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.1.0 |
| Built: | 2026-07-11 01:21:49 UTC |
| Source: | https://github.com/ttrotto/rusterize |
Extremely fast rasterization engine built in Rust for R
rusterize( data, like = NULL, resolution = NULL, out_shape = NULL, extent = NULL, field = NULL, by = NULL, burn = NULL, fun = "last", background = NA, encoding = "dense", all_touched = FALSE, tap = FALSE, dtype = "double" )rusterize( data, like = NULL, resolution = NULL, out_shape = NULL, extent = NULL, field = NULL, by = NULL, burn = NULL, fun = "last", background = NA, encoding = "dense", all_touched = FALSE, tap = FALSE, dtype = "double" )
data |
An |
like |
A |
resolution |
Pixel resolution as |
out_shape |
Output raster dimensions as |
extent |
Spatial bounding box as |
field |
Column name to use for pixel values. Mutually exclusive with |
by |
Column used for grouping. Each group is rasterized into a distinct band in the output. |
burn |
A static value or a list of values to apply to each geometries. If a vector, it must match the
length of the geometry data. Mutually exclusive with |
fun |
Pixel function to use when burning geometries. Available options: |
background |
Value assigned to pixels not covered by any geometry. Defaults to NA. |
encoding |
The format of the returned object: |
all_touched |
If True, every pixel touched by a geometry is burned. |
tap |
Target Aligned Pixels: aligns the extent to the pixel resolution. |
dtype |
Output data type: |
A terra object or a SparseArray in COOrdinate format.